{-# LANGUAGE NoImplicitPrelude #-}
module Foreign.Marshal.Unsafe.Compat (
  -- * Unsafe functions
  unsafeLocalState
) where

import Foreign.Marshal.Unsafe (unsafeLocalState)
